# Genesis 4 Lattice

::: genesis.version4.Lattice

## Beamline Elements

::: genesis.version4.Chicane
::: genesis.version4.Corrector
::: genesis.version4.Drift
::: genesis.version4.Line
::: genesis.version4.Marker
::: genesis.version4.PhaseShifter
::: genesis.version4.Quadrupole
::: genesis.version4.Undulator
